CallbackItem class

Constructors

CallbackItem({required String callbackName, required Function callbackHandler, bool? takesArguments = true})

Properties

callbackHandler ↔ Function
getter/setter pair
callbackName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
takesArguments ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited