RingBuffer<E> class

Constructors

RingBuffer(int limit)

Properties

hashCode int
The hash code for this object.
no setterinherited
iterator Iterator<E>
no setter
length int
no setter
limit int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(E value) → void
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLimit(int limit) → void
toList({bool growable = true}) List<E>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited